@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 
+from datetime import datetime
+
 import click
 
 from slow_start_rewatch.config import Config
 from slow_start_rewatch.scheduler import Scheduler
+from slow_start_rewatch.timer import Timer
 
 
 class App(object):
@@ -12,6 +15,7 @@ class App(object):
     def __init__(self, config: Config) -> None:
         """Initialize App."""
         self.config = config
+        self.timer = Timer(config)
         self.scheduler = Scheduler(config)
 
     def run(self) -> None:
@@ -28,7 +32,13 @@ class App(object):
         self.scheduler.load(self.config["username"])
 
     def start(self) -> None:
-        """Start the main run."""
+        """
+        Start the main run.
+
+        1. Wait until the scheduled time.
+
+        2. Proceed with the Post submission.
+        """
         post = self.scheduler.scheduled_post
 
         if post is None:
@@ -36,7 +46,10 @@ class App(object):
                 "Cannot start the countdown without the scheduled post.",
             )
 
-        click.echo("A post to be submitted: {0} - {1}".format(
+        self.timer.wait(post.submit_at)
+
+        click.echo("{0}: A post to be submitted: {1} - {2}".format(
+            datetime.now(),
             post.subreddit,
             post.title,
         ))
